@@ -1,8 +1,4 @@
-# -*- coding: utf-8 -*-
 """The data model build on the Core Scientific Dataset Model."""
-from __future__ import division
-from __future__ import print_function
-
 import datetime
 import json
 from urllib.parse import urlparse
@@ -36,7 +32,7 @@ __credits__ = ["Deepansh J. Srivastava"]
 __license__ = "BSD License"
 __maintainer__ = "Deepansh J. Srivastava"
 __status__ = "Beta"
-__version__ = "0.4"
+__version__ = "0.5"
 
 __all__ = [
     "parse_dict",
@@ -143,13 +139,13 @@ def load(filename=None, application=False, verbose=False):
     csdm_object = parse_dict(dictionary)
 
     if application is False:
-        csdm_object.application = {}
+        csdm_object.application = None
         for dim in csdm_object.dimensions:
-            dim.application = {}
+            dim.application = None
             if hasattr(dim, "reciprocal") and dim.type != "label":
-                dim.reciprocal.application = {}
+                dim.reciprocal.application = None
         for dim in csdm_object.dependent_variables:
-            dim.application = {}
+            dim.application = None
             # if hasattr(dim., 'dimension indexes'):
             #     dim.reciprocal.application = {}
     # csdm_objects = []
@@ -193,8 +189,8 @@ def new(description=""):
 
     Example:
         >>> import csdmpy as cp
-        >>> emptydata = cp.new(description='Testing Testing 1 2 3')
-        >>> print(emptydata.data_structure)
+        >>> empty_data = cp.new(description='Testing Testing 1 2 3')
+        >>> print(empty_data.data_structure)
         {
           "csdm": {
             "version": "1.0",
@@ -261,7 +257,7 @@ def plot(csdm_object, reverse_axis=None, range=None, **kwargs):
         csdm_object: The CSDM object.
         reverse_axis: An ordered array of boolean specifying which dimensions will be
             displayed on a reverse axis.
-        range: A list of minimum and maxmim coordinates along the dimensions. The range
+        range: A list of minimum and maximum coordinates along the dimensions. The range
             along each dimension is given as [min, max]
         kwargs: Additional keyword arguments are used in matplotlib plotting functions.
             We implement the following matplotlib methods for the one and
