@@ -1,8 +1,4 @@
-# -*- coding: utf-8 -*-
 """THE CSDM object"""
-from __future__ import division
-from __future__ import print_function
-
 import datetime
 import json
 import warnings
@@ -14,9 +10,7 @@ from astropy.units.quantity import Quantity
 from .abstract_list import __dimensions_list__  # lgtm [py/import-own-module]
 from .abstract_list import DependentVariableList  # lgtm [py/import-own-module]
 from .abstract_list import DimensionList  # lgtm [py/import-own-module]
-from .dependent_variable import (  # lgtm [py/import-own-module] # noqa: F401
-    as_dependent_variable,
-)
+from .dependent_variable import as_dependent_variable  # noqa: F401
 from .dependent_variable import DependentVariable  # lgtm [py/import-own-module]
 from .dimension import as_dimension  # lgtm [py/import-own-module]
 from .dimension import Dimension  # lgtm [py/import-own-module] # noqa: F401
@@ -67,7 +61,19 @@ __ufunc_list_unit_independent__ = [
 
 __ufunc_list_applies_to_unit__ = [np.sqrt, np.square, np.cbrt, np.reciprocal, np.power]
 
-__function_reduction_list__ = [np.max, np.min, np.sum, np.mean, np.var, np.std, np.prod]
+__function_reduction_list__ = [
+    np.max,
+    np.min,
+    np.sum,
+    np.mean,
+    np.var,
+    np.std,
+    np.prod,
+    np.cumsum,
+    np.cumprod,
+    np.argmin,
+    np.argmax,
+]
 
 __other_functions__ = [np.round, np.real, np.imag, np.clip, np.around, np.angle]
 
@@ -116,9 +122,9 @@ class CSDM:
         self._read_only = False
         self._version = version
         self._timestamp = ""
-        self._geographic_coordinate = {}
+        self._geographic_coordinate = None
         self._description = description
-        self._application = {}
+        self._application = None
         self._filename = filename
 
         kwargs_keys = kwargs.keys()
@@ -131,21 +137,23 @@ class CSDM:
 
         self._dimensions = DimensionList([])
         if "dimensions" in kwargs_keys:
-            if not isinstance(kwargs["dimensions"], list):
+            if not isinstance(kwargs["dimensions"], (list, DimensionList)):
                 t_ = type(kwargs["dimensions"])
                 raise ValueError(
-                    f"A list of valid Dimension objects or equivalent dictionary "
-                    f"objects is required, found {t_}"
+                    "A list of valid Dimension or equivalent dictionary objects is "
+                    f"required, found {t_}."
                 )
             _ = [self.dimensions.append(item) for item in kwargs["dimensions"]]
 
         self._dependent_variables = DependentVariableList([])
         if "dependent_variables" in kwargs_keys:
             t_ = type(kwargs["dependent_variables"])
-            if not isinstance(kwargs["dependent_variables"], list):
+            if not isinstance(
+                kwargs["dependent_variables"], (list, DependentVariableList)
+            ):
                 raise ValueError(
-                    f"A list of valid DependentVariable objects or equivalent "
-                    f"dictionary objects is required, found {t_}"
+                    "A list of valid DependentVariable or equivalent dictionary "
+                    f"objects is required, found {t_}."
                 )
             for item in kwargs["dependent_variables"]:
                 if isinstance(item, dict):
@@ -200,7 +208,7 @@ class CSDM:
         """
         if len(self.dependent_variables) != len(other.dependent_variables):
             raise Exception(
-                "Cannot operate on CSDM objects with differnet lengths of "
+                "Cannot operate on CSDM objects with different lengths of "
                 "dependent variables."
             )
 
@@ -208,11 +216,11 @@ class CSDM:
         """Check if the dependent variables from the two csdm objects have the same
         dimensionality.
         """
-        for v1, v2 in zip(self.dependent_variables, other.dependent_variables):
-            if v1.unit.physical_type != v2.unit.physical_type:
+        for v_1, v_2 in zip(self.dependent_variables, other.dependent_variables):
+            if v_1.unit.physical_type != v_2.unit.physical_type:
                 raise Exception(
                     "Cannot operate on dependent variables with physical types: "
-                    f"{v1.unit.physical_type} and {v2.unit.physical_type}."
+                    f"{v_1.unit.physical_type} and {v_2.unit.physical_type}."
                 )
 
     def __check_csdm_object_additive_compatibility(self, other):
@@ -295,19 +303,19 @@ class CSDM:
 
             for i, item in enumerate(self.dependent_variables):
                 factor = other.dependent_variables[i].unit.to(item.unit)
-                fn = getattr(item.components, function)
-                fn(factor * other.dependent_variables[i].components)
+                f_n = getattr(item.components, function)
+                f_n(factor * other.dependent_variables[i].components)
             return self
 
         other = check_scalar_object(other, symbol)
 
         for i, item in enumerate(self.dependent_variables):
-            fn = getattr(item.components, function)
+            f_n = getattr(item.components, function)
             if not isinstance(other, Quantity):
-                fn(other)
+                f_n(other)
             else:
                 factor = other.unit.to(item.unit)
-                fn(factor * other.value)
+                f_n(factor * other.value)
         return self
 
     def _default_addition_(self, other, fn, operation):
@@ -346,10 +354,10 @@ class CSDM:
     def __add__(self, other):
         """Add two objects (z=x+y)"""
 
-        def fn(a, b):
+        def function(a, b):
             return a * b
 
-        return self._default_addition_(other, fn, "+")
+        return self._default_addition_(other, function, "+")
 
     def __radd__(self, other):
         """Right add two objects. See __add__ for details."""
@@ -362,17 +370,17 @@ class CSDM:
     def __sub__(self, other):
         """Subtract two objects (z=x+y)"""
 
-        def fn(a, b):
+        def function(a, b):
             return -a * b
 
-        return self._default_addition_(other, fn, "-")
+        return self._default_addition_(other, function, "-")
 
     def __rsub__(self, other):
         """Right subtract two objects. See __sub__ for details."""
         return -self.__sub__(other)
 
     def __isub__(self, other):
-        """Subtract two objects in-lace (y-=x). See __sub__ for details. """
+        """Subtract two objects in-lace (y-=x). See __sub__ for details."""
         return self.__ifunction__("__isub__", "-", other)
 
     def __mul__(self, other):
@@ -448,18 +456,18 @@ class CSDM:
         other = check_scalar_object(other, "**")
         for item in self.dependent_variables:
             item.components.__ipow__(other)
-            item.subtype._unit = item.subtype._unit ** other
+            item.subtype._unit = item.subtype._unit**other
         return self
 
     def _get_indices(self, indices):
         if isinstance(indices, tuple):
             l_ = len(indices)
             indices = indices + tuple(
-                [slice(0, _.count, 1) for _ in self.dimensions[l_:]]
+                slice(0, _.count, 1) for _ in self.dimensions[l_:]
             )
         if isinstance(indices, (int, slice)):
             indices = (indices,) + tuple(
-                [slice(0, _.count, 1) for _ in self.dimensions[1:]]
+                slice(0, _.count, 1) for _ in self.dimensions[1:]
             )
         for item in indices:
             if isinstance(item, (tuple, list)):
@@ -641,9 +649,9 @@ class CSDM:
         .. doctest::
 
             >>> print(data.application)
-            {}
+            None
 
-        By default, the application attribute is an empty dictionary, that is,
+        By default, the application attribute is an empty object, that is,
         the application metadata stored by the previous application is ignored
         upon file import.
 
@@ -673,7 +681,7 @@ class CSDM:
 
     @application.setter
     def application(self, value):
-        self._application = validate(value, "application", dict)
+        self._application = validate(value, "application", (dict, type(None)))
 
     @property
     def data_structure(self):
@@ -694,7 +702,7 @@ class CSDM:
 
     @property
     def filename(self):
-        """Local file address of the current file. """
+        """Local file address of the current file."""
         return self._filename
 
     # Numpy - like property
@@ -729,7 +737,7 @@ class CSDM:
     @property
     def shape(self):
         """Return the count along each dimension of the csdm object."""
-        return tuple([item.count for item in self._dimensions])
+        return tuple(item.count for item in self._dimensions)
 
     @property
     def size(self):
@@ -754,44 +762,34 @@ class CSDM:
         .. doctest::
 
             >>> import csdmpy as cp
-            >>> datamodel = cp.new()
+            >>> data_model = cp.new()
             >>> py_dictionary = {
-            ...     'type': 'linear',
-            ...     'increment': '5 G',
-            ...     'count': 50,
-            ...     'coordinates_offset': '-10 mT'
+            ...     "type": "linear",
+            ...     "increment": "5 G",
+            ...     "count": 50,
+            ...     "coordinates_offset": "-10 mT",
             ... }
-            >>> datamodel.add_dimension(py_dictionary)
+            >>> data_model.add_dimension(py_dictionary)
 
         *Using keyword as the arguments.*
 
         .. doctest::
 
-            >>> datamodel.add_dimension(
-            ...     type = 'linear',
-            ...     increment = '5 G',
-            ...     count = 50,
-            ...     coordinates_offset = '-10 mT'
-            ... )
+            >>> data_model.add_dimension(type="linear", increment="5 G", count=50)
 
         *Using a* :ref:`dim_api` *class.*
 
         .. doctest::
 
-            >>> var1 = Dimension(type = 'linear',
-            ...                  increment = '5 G',
-            ...                  count = 50,
-            ...                  coordinates_offset = '-10 mT')
-            >>> datamodel.add_dimension(var1)
+            >>> var1 = Dimension(type="linear", increment="5 G", count=50)
+            >>> data_model.add_dimension(var1)
 
         *Using a subtype class.*
 
         .. doctest::
 
-            >>> var2 = cp.LinearDimension(count = 50,
-            ...                  increment = '5 G',
-            ...                  coordinates_offset = '-10 mT')
-            >>> datamodel.add_dimension(var2)
+            >>> var2 = cp.LinearDimension(count=50, increment="5 G")
+            >>> data_model.add_dimension(var2)
 
         *From a numpy array.*
 
@@ -799,11 +797,11 @@ class CSDM:
 
             >>> array = np.arange(50)
             >>> dim = cp.as_dimension(array)
-            >>> datamodel.add_dimension(dim)
+            >>> data_model.add_dimension(dim)
 
         In the third and fourth example, the instances, ``var1`` and ``var2`` are added
-        to the ``datamodel`` as a reference, `i.e.`, if the instance ``var1`` or
-        ``var2`` is destroyed, the ``datamodel`` instance will become corrupt. As a
+        to the ``data_model`` as a reference, `i.e.`, if the instance ``var1`` or
+        ``var2`` is destroyed, the ``data_model`` instance will become corrupt. As a
         recommendation, always pass a copy of the :ref:`dim_api` instance to the
         :meth:`~csdmpy.CSDM.add_dimension` method.
 
@@ -823,11 +821,6 @@ class CSDM:
 
         self._dimensions += [Dimension(*args, **kwargs)]
 
-    # deprecated
-    def add_x(self, *args, **kwargs):
-        """Alias to the ``add_dimension`` method."""
-        self.add_dimension(*args, **kwargs)
-
     def add_dependent_variable(self, *args, **kwargs):
         """Add a new :ref:`dv_api` instance to the :ref:`csdm_api` instance.
 
@@ -838,40 +831,44 @@ class CSDM:
 
             >>> import numpy as np
 
-            >>> datamodel = cp.new()
+            >>> data_model = cp.new()
 
-            >>> numpy_array = (100*np.random.rand(3,50)).astype(np.uint8)
+            >>> numpy_array = (100 * np.random.rand(3, 50)).astype(np.uint8)
             >>> py_dictionary = {
-            ...     'type': 'internal',
-            ...     'components': numpy_array,
-            ...     'name': 'star',
-            ...     'unit': 'W s',
-            ...     'quantity_name': 'energy',
-            ...     'quantity_type': 'pixel_3'
+            ...     "type": "internal",
+            ...     "components": numpy_array,
+            ...     "name": "star",
+            ...     "unit": "W s",
+            ...     "quantity_name": "energy",
+            ...     "quantity_type": "pixel_3",
             ... }
-            >>> datamodel.add_dependent_variable(py_dictionary)
+            >>> data_model.add_dependent_variable(py_dictionary)
 
         *From a list of valid keyword arguments.*
 
         .. doctest::
 
-            >>> datamodel.add_dependent_variable(type='internal',
-            ...                                  name='star',
-            ...                                  unit='W s',
-            ...                                  quantity_type='pixel_3',
-            ...                                  components=numpy_array)
+            >>> data_model.add_dependent_variable(
+            ...     type="internal",
+            ...     name="star",
+            ...     unit="W s",
+            ...     quantity_type="pixel_3",
+            ...     components=numpy_array,
+            ... )
 
         *From a* :ref:`dv_api` *instance.*
 
         .. doctest::
 
             >>> from csdmpy import DependentVariable
-            >>> var1 = DependentVariable(type='internal',
-            ...                          name='star',
-            ...                          unit='W s',
-            ...                          quantity_type='pixel_3',
-            ...                          components=numpy_array)
-            >>> datamodel.add_dependent_variable(var1)
+            >>> var1 = DependentVariable(
+            ...     type="internal",
+            ...     name="star",
+            ...     unit="W s",
+            ...     quantity_type="pixel_3",
+            ...     components=numpy_array,
+            ... )
+            >>> data_model.add_dependent_variable(var1)
 
         If passing a :ref:`dv_api` instance, as a general recommendation,
         always pass a copy of the DependentVariable instance to the
@@ -888,20 +885,16 @@ class CSDM:
             DeprecationWarning,
         )
         if args != () and isinstance(args[0], DependentVariable):
-            dv = args[0]
+            d_v = args[0]
         else:
-            dv = DependentVariable(filename=self.filename, *args, **kwargs)
-            dv.encoding = "base64"
-            dv.type = "internal"
+            d_v = DependentVariable(filename=self.filename, *args, **kwargs)
+            d_v.encoding = "base64"
+            d_v.type = "internal"
 
         if self.shape != ():
-            dv._reshape(self.shape[::-1])
+            d_v._reshape(self.shape[::-1])
 
-        self._dependent_variables += [dv]
-
-    def add_y(self, *args, **kwargs):
-        """Alias for ``add_dependent_variable`` method."""
-        return self.add_dependent_variable(*args, **kwargs)
+        self._dependent_variables += [d_v]
 
     def to_dict(self, update_timestamp=False, read_only=False):
         """Alias to the `dict()` method of the class."""
@@ -924,13 +917,13 @@ class CSDM:
         self,
         filename=None,
         update_timestamp=False,
-        read_only=False,
-        version=__latest_CSDM_version__,
+        read_only=None,
+        version=None,
         for_display=False,
     ):
         obj = {}
-        obj["version"] = self.version
-        obj["read_only"] = self.read_only
+        obj["version"] = self.version if version is None else version
+        obj["read_only"] = self.read_only if read_only is None else read_only
         obj["timestamp"] = (
             datetime.datetime.utcnow().isoformat()[:-7] + "Z"
             if update_timestamp
@@ -946,44 +939,30 @@ class CSDM:
             for i, dv in enumerate(self.dependent_variables)
         ]
 
-        empty_values = [[], "", {}, False]
+        empty_values = [[], "", {}, False, None]
         _ = [obj.pop(_) for _ in [k for k, v in obj.items() if v in empty_values]]
 
         return {"csdm": obj}
 
-    def dumps(
-        self,
-        update_timestamp=False,
-        read_only=False,
-        version=__latest_CSDM_version__,
-        **kwargs,
-    ):
+    def dumps(self, update_timestamp=False, read_only=False, **kwargs):
         """Serialize the :ref:`CSDM_api` instance as a JSON data-exchange string.
 
         Args:
             update_timestamp(bool): If True, timestamp is updated to current time.
             read_only (bool): If true, the file is serialized as read_only.
-            version (str): The file is serialized with the given CSD model version.
 
         Example:
             >>> data.dumps()[:63] # first 63 characters
             '{"csdm": {"version": "1.0", "timestamp": "1994-11-05T13:15:30Z"'
         """
         dict_ = self._dict(
-            update_timestamp=update_timestamp, read_only=read_only, version=version
+            update_timestamp=update_timestamp, read_only=read_only, version=self.version
         )
         return json.dumps(
             dict_, ensure_ascii=False, sort_keys=False, allow_nan=False, **kwargs
         )
 
-    def save(
-        self,
-        filename="",
-        read_only=False,
-        version=__latest_CSDM_version__,
-        output_device=None,
-        indent=0,
-    ):
+    def save(self, filename="", read_only=False, output_device=None, indent=0):
         """Serialize the :ref:`CSDM_api` instance as a JSON data-exchange file.
 
         There are two types of file serialization extensions, `.csdf` and
@@ -1015,7 +994,6 @@ class CSDM:
         Args:
             filename (str): The filename of the serialized file.
             read_only (bool): If true, the file is serialized as read_only.
-            version (str): The file is serialized with the given CSD model version.
             output_device(object): Object where the data is written. If provided,
                 the argument `filename` become irrelevant.
 
@@ -1023,10 +1001,12 @@ class CSDM:
             >>> data.save('my_file.csdf')
 
         .. testcleanup::
-            >>> import os
-            >>> os.remove('my_file.csdf')
+
+            import os
+
+            os.remove("my_file.csdf")
         """
-        dictionary = self._dict(filename=filename, version=version)
+        dictionary = self._dict(filename=filename, version=self.version)
 
         timestamp = datetime.datetime.utcnow().isoformat()[:-7] + "Z"
         dictionary["csdm"]["timestamp"] = timestamp
@@ -1118,15 +1098,15 @@ class CSDM:
 
     # csdm dimension order manipulation
     def transpose(self):
-        """Return a transpose of the dependent variable data from the CSDM object."""
+        """Return a transpose of the CSDM object."""
         return self.T
 
     def fft(self, axis=0):
-        """Perform a FFT along the given `dimension=axis`, for linear dimension assuming
-        Nyquist-shannan relation.
+        """Perform a FFT along the given `dimension=axis`, for linear dimension, assuming
+        Nyquist-Shannon relation.
 
         Args:
-            axis: The index of the dimension along which the FFT is performed.
+            axis: dimension index along which the FFT is performed.
 
         The FFT method uses the :attr:`~csdmpy.Dimension.complex_fft` attribute of the
         Dimension object to decide whether a forward or inverse Fourier transform is
@@ -1160,14 +1140,12 @@ class CSDM:
     #                            NumPy-like functions                         #
     # ----------------------------------------------------------------------- #
     def max(self, axis=None):
-        """Return a csdm object with the maximum dependent variable component along a
-        given axis.
+        """Return a csdm object of maximum dependent variable along a given axis.s
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the sum of the dependent
-                variable components is performed. If None, the output is the sum over
-                all dimensions per dependent variable.
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If None,
+                the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a numpy array when dimension
             is None.
@@ -1179,24 +1157,47 @@ class CSDM:
         return np.max(self, axis=axis)
 
     def argmax(self, axis=None):
-        raise NotImplementedError("")
+        """Return a csdm object of argmax dependent variable along a given axis.s
+
+        Args:
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If None,
+                the output is over all dimensions per dependent variable.
+        Return:
+            A CSDM object with `m` dimensions removed, or a numpy array when dimension
+            is None.
+
+        Example:
+            >>> data.max()
+            <Quantity 0.95105654>
+        """
+        return np.argmax(self, axis=axis)
 
     def min(self, axis=None):
-        """Return a csdm object with the minimum dependent variable component along a
+        """Return a csdm object of minimum dependent variable component along a
         given axis.
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the sum of the dependent
-                variable components is performed. If None, the output is over all
-                dimensions per dependent variable.
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If
+                None, the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a list when `axis` is None.
         """
         return np.min(self, axis=axis)
 
     def argmin(self, axis=None):
-        raise NotImplementedError("")
+        """Return a csdm object of argmin dependent variable component along a
+        given axis.
+
+        Args:
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If
+                None, the output is over all dimensions per dependent variable.
+        Return:
+            A CSDM object with `m` dimensions removed, or a list when `axis` is None.
+        """
+        return np.argmin(self, axis=axis)
 
     def ptp(self, axis=None):
         raise NotImplementedError("")
@@ -1226,93 +1227,99 @@ class CSDM:
         return np.clip(self, a_min, a_max)
 
     def conj(self):
-        """Return a csdm object with the complex conjugate of all dependent variable
-        components."""
+        """Return a complex conjugate of the csdm object."""
         return np.conj(self)
 
     def round(self, decimals=0):
-        """Return a csdm object by rounding the dependent variable components to the
-        given `decimals`."""
+        """Rounds a csdm object to the given `decimals`."""
         return np.round(self, decimals)
 
     def trace(self, offset=0, axis1=0, axis2=-1):
         raise NotImplementedError("")
 
     def sum(self, axis=None):
-        """Return a csdm object with the sum of the dependent variable components over
-        a given `dimension=axis`.
+        """Return a csdm object sum over a given axis.
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the sum of the dependent
-                variable components is performed. If None, the output is over all
-                dimensions per dependent variable.
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If None,
+                the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a list when `axis` is None.
         """
         return np.sum(self, axis=axis)
 
     def cumsum(self, axis=None):
-        raise NotImplementedError("")
-
-    def mean(self, axis=None):
-        """Return a csdm object with the mean of the dependent variable components over
-        a given `dimension=axis`.
+        """Return a csdm object cumulative sum over a given axis.
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the sum of the dependent
-                variable components is performed. If None, the output is over all
-                dimensions per dependent variable.
+            axis: An integer or None corresponding to the dimension index along which
+                the operation is performed. If None, the output is over all dimensions
+                per dependent variable.
+        Return:
+            A CSDM object with `1` dimension removed, or a list when `axis` is None.
+        """
+        return np.cumsum(self, axis=axis)
+
+    def mean(self, axis=None):
+        """Return a csdm object mean over a given axis.
+
+        Args:
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If None,
+                the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a list when `axis` is None.
         """
         return np.mean(self, axis=axis)
 
     def var(self, axis=None):
-        """Return a csdm object with the variance of the dependent variable components
-        over a given `dimension=axis`.
+        """Return a csdm object variance over a given axis.
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the sum of the dependent
-                variable components is performed. If None, the output is over all
-                dimensions per dependent variable.
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed. If None,
+                the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a list when `axis` is None.
         """
         return np.var(self, axis=axis)
 
     def std(self, axis=None):
-        """Return a csdm object with the standard deviation of the dependent variable
-        components over a given `dimension=axis`.
+        """Return a csdm object standard deviation over a given axis.
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the sum of the dependent
-                variable components is performed. If None, the output is over all
-                dimensions per dependent variable.
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimensions index/indices along which the operation is performed.
+                If None, the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a list when `axis` is None.
         """
         return np.std(self, axis=axis)
 
     def prod(self, axis=None):
-        """Return a csdm object with the product of the dependent variable components
-        over a given `dimension=axis`.
+        """Return a csdm object product over a given axis.
 
         Args:
-            axis: An integer or None or a tuple of `m` integers cooresponding to the
-                index/indices of dimensions along which the product of the dependent
-                variable components is performed. If None, the output is over all
-                dimensions per dependent variable.
+            axis: An integer or None or a tuple of `m` integers corresponding to the
+                dimension index/indices along which the operation is performed.
+                If None, the output is over all dimensions per dependent variable.
         Return:
             A CSDM object with `m` dimensions removed, or a list when `axis` is None.
         """
         return np.prod(self, axis=axis)
 
     def cumprod(self, axis=None):
-        raise NotImplementedError("")
+        """Return a csdm object cumulative product over a given axis.
+
+        Args:
+            axis: An integer or None corresponding to the dimension index along which
+                the operation is performed. If None, the output is over all dimensions
+                per dependent variable.
+        Return:
+            A CSDM object with `m` dimensions removed, or a list when `axis` is None.
+        """
+        return np.cumprod(self, axis=axis)
 
     def __array_ufunc__(self, function, method, *inputs, **kwargs):
         csdm = inputs[0]
@@ -1350,7 +1357,7 @@ class CSDM:
 
         raise NotImplementedError(f"Function {function} is not implemented.")
 
-    def __array_function__(self, function, types, *args, **kwargs):
+    def __array_function__(self, function, _, *args, **kwargs):
         if function in __function_reduction_list__:
             return _get_new_csdm_object_after_dimension_reduction_func(
                 function, *args[0], **args[1], **kwargs
@@ -1364,18 +1371,28 @@ class CSDM:
                 args[1]["axes"] = (0,) + tuple(np.asarray(args[1]["axes"]) + 1)
             else:
                 dim_len = len(args[0][0].dimensions)
-                args[1]["axes"] = (0,) + tuple([-i - 1 for i in range(dim_len)])
+                args[1]["axes"] = (0,) + tuple(-i - 1 for i in range(dim_len))
 
             csdm = _get_new_csdm_object_after_applying_function(
                 function, *args[0], **args[1], **kwargs
             )
             csdm._dimensions = tuple(
-                [
-                    csdm.dimensions[args[1]["axes"][1:][i]]
-                    for i in range(len(csdm.dimensions))
-                ]
+                csdm.dimensions[args[1]["axes"][1:][i]]
+                for i in range(len(csdm.dimensions))
             )
 
+        # if function in __return_np__:
+        #     if len(self.y) > 1:
+        #         raise NotImplementedError(
+        #             f"Function {function.__name__} is not implemented for multi "
+        #              "dependent variable csdm object."
+        #         )
+        #     csdm, args_, axis, kwargs = _get_CSDM_object__args__axes(
+        #         *args[0], **args[1], **kwargs
+        #     )
+        #     nd_array = csdm.y[0].components
+        #     return function(nd_array, *args_, **kwargs)
+
         raise NotImplementedError(f"Function {function.__name__} is not implemented.")
 
     # def __array_interface__(self, *args, **kwargs):
@@ -1393,7 +1410,7 @@ class CSDM:
             csdm_object: The CSDM object.
             reverse_axis: An ordered array of boolean specifying which dimensions will
                 be displayed on a reverse axis.
-            range: A list of minimum and maxmim coordinates along the dimensions. The
+            range: A list of minimum and maximum coordinates along the dimensions. The
                 range along each dimension is given as [min, max]
             kwargs: Additional keyword arguments are used in matplotlib plotting
                 functions. We implement the following matplotlib methods for the one
@@ -1448,13 +1465,13 @@ def _get_new_csdm_object_after_applying_ufunc(
     new._dimensions = deepcopy(csdm.dimensions)
 
     for i, variable in enumerate(csdm.dependent_variables):
-        y = func(variable.components * factor[i], *inputs, **kwargs)
+        res = func(variable.components * factor[i], *inputs, **kwargs)
 
         obj = empty_dependent_variable(
-            numeric_type=y.dtype, quantity_type=variable.quantity_type
+            numeric_type=res.dtype, quantity_type=variable.quantity_type
         )
         obj._copy_metadata(variable)
-        obj.subtype._components = y
+        obj.subtype._components = res
         new._dependent_variables += [obj]
         # obj = as_dependent_variable(y, quantity_type=variable.quantity_type)
         # obj._copy_metadata(variable)
@@ -1499,6 +1516,7 @@ def _get_new_csdm_object_after_apodization(csdm, func, arg, index=-1):
     return the corresponding CSDM object.
     """
     index = _check_dimension_indices(len(csdm.dimensions), index)
+    index = [index] if isinstance(index, int) else index
 
     quantity = string_to_quantity(arg)
 
@@ -1545,6 +1563,7 @@ def _get_new_csdm_object_after_apodization(csdm, func, arg, index=-1):
 
 
 def _get_CSDM_object__args__axes(*args, **kwargs):
+    # print(args)
     axis = None
     args_ = []
     if args != ():
@@ -1574,6 +1593,7 @@ def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
     new = CSDM()
     lst = []
 
+    axis = [axis] if isinstance(axis, int) else axis
     # dimension should be added first so that the dependent variables can be
     # shaped appropriately.
     if axis is not None:
