@@ -1,16 +1,12 @@
-# -*- coding: utf-8 -*-
 """Dependent variable object: attributes and methods."""
-from __future__ import division
-from __future__ import print_function
-
 import json
 import warnings
 from copy import deepcopy
 
 import numpy as np
 
-from .external import ExternalDataset  # lgtm [py/import-own-module]
-from .internal import InternalDataset  # lgtm [py/import-own-module]
+from csdmpy.dependent_variable.external import ExternalDataset
+from csdmpy.dependent_variable.internal import InternalDataset
 from csdmpy.utils import _axis_label  # lgtm [py/import-own-module]
 from csdmpy.utils import _get_dictionary  # lgtm [py/import-own-module]
 
@@ -38,15 +34,15 @@ class DependentVariable:
 
         >>> from csdmpy import DependentVariable
         >>> import numpy as np
-        >>> numpy_array = np.arange(30).reshape(3,10).astype(np.float32)
+        >>> numpy_array = np.arange(30).reshape(3, 10).astype(np.float32)
 
         >>> dependent_variable_dictionary = {
-        ...     'type': 'internal',
-        ...     'components': numpy_array,
-        ...     'name': 'star',
-        ...     'unit': 'W s',
-        ...     'quantity_name': 'energy',
-        ...     'quantity_type': 'pixel_3'
+        ...     "type": "internal",
+        ...     "components": numpy_array,
+        ...     "name": "star",
+        ...     "unit": "W s",
+        ...     "quantity_name": "energy",
+        ...     "quantity_type": "pixel_3",
         ... }
         >>> y = DependentVariable(dependent_variable_dictionary)
 
@@ -57,12 +53,12 @@ class DependentVariable:
     .. doctest::
 
         >>> y = DependentVariable(
-        ...         type='internal',
-        ...         name='star',
-        ...         unit='W s',
-        ...         quantity_type='pixel_3',
-        ...         components=numpy_array
-        ...     )
+        ...     type="internal",
+        ...     name="star",
+        ...     unit="W s",
+        ...     quantity_type="pixel_3",
+        ...     components=numpy_array,
+        ... )
     """
 
     __slots__ = ("subtype", "_type")
@@ -84,7 +80,7 @@ class DependentVariable:
             "components": None,
             "components_url": None,
             "filename": __file__,
-            "application": {},
+            "application": None,
             "sparse_sampling": {},
         }
         input_dict = _get_dictionary(*args, **kwargs)
@@ -108,9 +104,9 @@ class DependentVariable:
             )
 
         if input_dict["type"] not in ["internal", "external"]:
-            t_ = input_dict["type"]
+            t_1 = input_dict["type"]
             raise ValueError(
-                f"The value, '{t_}', is an invalid `type` for the DependentVariable "
+                f"The value, '{t_1}', is an invalid `type` for the DependentVariable "
                 "objects. The allowed values are 'internal', 'external'."
             )
 
@@ -141,9 +137,9 @@ class DependentVariable:
 
     def __str__(self):
         msg = f"{self.components.__str__()} {self.unit}".strip()
-        qt = self.quantity_type
-        nt = self.numeric_type
-        return f"DependentVariable(\n{msg}, quantity_type={qt}, numeric_type={nt})"
+        q_t = self.quantity_type
+        n_t = self.numeric_type
+        return f"DependentVariable(\n{msg}, quantity_type={q_t}, numeric_type={n_t})"
 
     def __eq__(self, other):
         if not isinstance(other, DependentVariable):
@@ -160,7 +156,7 @@ class DependentVariable:
         .. doctest::
 
             >>> print(y.application)
-            {}
+            None
 
         The application attribute is where an application can place its own
         metadata as a python dictionary object containing the application specific
@@ -169,11 +165,7 @@ class DependentVariable:
 
         .. doctest::
 
-            >>> y.application = {
-            ...     "com.example.myApp" : {
-            ...         "myApp_key": "myApp_metadata"
-            ...      }
-            ... }
+            >>> y.application = {"com.example.myApp": {"myApp_key": "myApp_metadata"}}
             >>> print(y.application)
             {'com.example.myApp': {'myApp_key': 'myApp_metadata'}}
 
@@ -194,7 +186,7 @@ class DependentVariable:
 
         This attribute is not a part of the original core scientific dataset
         model, however, it is a convenient supplementary attribute that provides
-        formated string ready for labeling the components of the dependent variable.
+        formatted string ready for labeling the components of the dependent variable.
         The string at index `i` is formatted as `component_labels[i] / unit` if
         `component_labels[i]` is a non-empty string, otherwise, `quantity_name / unit`.
         Here, `quantity_name`, `component_labels`, and `unit`are the attributes of the
@@ -206,7 +198,7 @@ class DependentVariable:
             ['energy / (s W)', 'energy / (s W)', 'energy / (s W)']
 
         Returns:
-            A list of formated component label strings.
+            A list of formatted component label strings.
 
         Raises:
             AttributeError: When assigned a value.
@@ -235,7 +227,7 @@ class DependentVariable:
 
         .. doctest::
 
-            >>> y.component_labels = ['channel 0', 'channel 1', 'channel 2']
+            >>> y.component_labels = ["channel 0", "channel 1", "channel 2"]
 
         The individual labels are accessed with proper indexing, for example,
 
@@ -298,7 +290,7 @@ class DependentVariable:
 
         .. doctest::
 
-            >>> y.components = np.linspace(0,256,30, dtype='u1').reshape(3,10)
+            >>> y.components = np.linspace(0, 256, 30, dtype="u1").reshape(3, 10)
             >>> y.numeric_type
             'uint8'
 
@@ -400,7 +392,7 @@ class DependentVariable:
 
             >>> print(y.description)
             A test image
-            >>> y.description = 'A test pixel_3 image'
+            >>> y.description = "A test pixel_3 image"
             >>> print(y.description)
             A test pixel_3 image
 
@@ -438,7 +430,7 @@ class DependentVariable:
 
         .. doctest::
 
-            >>> y.encoding = 'base64'
+            >>> y.encoding = "base64"
 
         The value of this attribute will be used in serializing the data to the file,
         when using the :meth:`~csdmpy.CSDM.save` method.
@@ -463,7 +455,7 @@ class DependentVariable:
 
             >>> y.name
             'star'
-            >>> y.name = 'rock star'
+            >>> y.name = "rock star"
 
         Returns:
             A string containing the name of the dependent variable.
@@ -508,14 +500,14 @@ class DependentVariable:
              [10. 11. 12. 13. 14. 15. 16. 17. 18. 19.]
              [20. 21. 22. 23. 24. 25. 26. 27. 28. 29.]]
 
-            >>> y.numeric_type = 'complex64'
-            >>> print(y.components[:,:5])
+            >>> y.numeric_type = "complex64"
+            >>> print(y.components[:, :5])
             [[ 0.+0.j  1.+0.j  2.+0.j  3.+0.j  4.+0.j]
              [10.+0.j 11.+0.j 12.+0.j 13.+0.j 14.+0.j]
              [20.+0.j 21.+0.j 22.+0.j 23.+0.j 24.+0.j]]
 
-            >>> y.numeric_type = float # python type object
-            >>> print(y.components[:,:5])
+            >>> y.numeric_type = float  # python type object
+            >>> print(y.components[:, :5])
             [[ 0.  1.  2.  3.  4.]
              [10. 11. 12. 13. 14.]
              [20. 21. 22. 23. 24.]]
@@ -548,7 +540,7 @@ class DependentVariable:
         Raises:
             NotImplementedError: When assigning a value.
         """
-        return self.subtype.quantity_name
+        return str(self.subtype.quantity_name)
 
     @quantity_name.setter
     def quantity_name(self, value=""):
@@ -573,7 +565,7 @@ class DependentVariable:
 
             >>> y.quantity_type
             'pixel_3'
-            >>> y.quantity_type = 'vector_3'
+            >>> y.quantity_type = "vector_3"
 
         Returns:
             A string with a `valid` quantity type.
@@ -607,7 +599,7 @@ class DependentVariable:
             >>> print(y.type)
             internal
 
-            >>> y.type = 'external'
+            >>> y.type = "external"
 
         When `type` is external, the data values from the corresponding dependent
         variable are serialized to an external file within the same directory as the
@@ -627,11 +619,9 @@ class DependentVariable:
             self._type = value
             return
         raise ValueError(
-            (
-                f"The value, `{value}`, is invalid for the `type` attribute of the "
-                "DependentVariable object. The allowed values are 'internal' and "
-                "'external'."
-            )
+            f"The value, `{value}`, is invalid for the `type` attribute of the "
+            "DependentVariable object. The allowed values are 'internal' and "
+            "'external'."
         )
 
     @property
@@ -678,12 +668,12 @@ class DependentVariable:
 
             >>> y.unit
             Unit("s W")
-            >>> print(y.components[0,5])
+            >>> print(y.components[0, 5])
             5.0
-            >>> y.to('mJ')
+            >>> y.to("mJ")
             >>> y.unit
             Unit("mJ")
-            >>> print(y.components[0,5])
+            >>> print(y.components[0, 5])
             5000.0
 
         .. note::
@@ -742,11 +732,9 @@ class DependentVariable:
 
         if grid_points != components_size and item._sparse_sampling == {}:
             warnings.warn(
-                (
-                    "The number of elements in the components array, "
-                    f"{components_size}, is not consistent with the total "
-                    f"number of grid points, {grid_points}."
-                )
+                "The number of elements in the components array, "
+                f"{components_size}, is not consistent with the total "
+                f"number of grid points, {grid_points}."
             )
         if item._sparse_sampling == {}:
             item._components = np.asarray(
