@@ -1,13 +1,12 @@
-# -*- coding: utf-8 -*-
 """The Dimension object: attributes and methods."""
 import warnings
 from copy import deepcopy
 
 import numpy as np
 
-from .labeled import LabeledDimension  # lgtm [py/import-own-module]
-from .linear import LinearDimension  # lgtm [py/import-own-module]
-from .monotonic import MonotonicDimension  # lgtm [py/import-own-module]
+from csdmpy.dimension.labeled import LabeledDimension
+from csdmpy.dimension.linear import LinearDimension
+from csdmpy.dimension.monotonic import MonotonicDimension
 from csdmpy.units import string_to_quantity  # lgtm [py/import-own-module]
 from csdmpy.utils import _get_dictionary  # lgtm [py/import-own-module]
 from csdmpy.utils import validate  # lgtm [py/import-own-module]
@@ -33,7 +32,7 @@ DEFAULT_DIM = {
     "period": None,  # valid for monotonic and linear subtypes
     "quantity_name": None,  # valid for monotonic and linear subtypes
     "label": "",  # valid for all dimension subtypes
-    "application": {},  # valid for all dimension subtypes
+    "application": None,  # valid for all dimension subtypes
     "reciprocal": {  # valid for monotonic and linear subtypes
         "increment": None,  # valid for monotonic and linear subtypes
         "coordinates_offset": None,  # valid for monotonic and linear subtypes
@@ -42,7 +41,7 @@ DEFAULT_DIM = {
         "quantity_name": None,  # valid for monotonic and linear subtypes
         "label": "",  # valid for monotonic and linear subtypes
         "description": "",  # valid for monotonic and linear subtypes
-        "application": {},  # valid for monotonic and linear subtypes
+        "application": None,  # valid for monotonic and linear subtypes
     },
 }
 
@@ -67,12 +66,12 @@ class Dimension:
 
         >>> from csdmpy import Dimension
         >>> dimension_dictionary = {
-        ...     'type': 'linear',
-        ...     'description': 'test',
-        ...     'increment': '5 G',
-        ...     'count': 10,
-        ...     'coordinates_offset': '10 mT',
-        ...     'origin_offset': '10 T'
+        ...     "type": "linear",
+        ...     "description": "test",
+        ...     "increment": "5 G",
+        ...     "count": 10,
+        ...     "coordinates_offset": "10 mT",
+        ...     "origin_offset": "10 T",
         ... }
         >>> x = Dimension(dimension_dictionary)
 
@@ -82,12 +81,14 @@ class Dimension:
 
     .. doctest::
 
-        >>> x = Dimension(type = 'linear',
-        ...               description = 'test',
-        ...               increment = '5 G',
-        ...               count = 10,
-        ...               coordinates_offset = '10 mT',
-        ...               origin_offset = '10 T')
+        >>> x = Dimension(
+        ...     type="linear",
+        ...     description="test",
+        ...     increment="5 G",
+        ...     count=10,
+        ...     coordinates_offset="10 mT",
+        ...     origin_offset="10 T",
+        ... )
     """
 
     __slots__ = ("subtype",)
@@ -103,10 +104,10 @@ class Dimension:
             raise KeyError("Missing a required 'type' key from the Dimension object.")
 
         if "reciprocal" in input_keys:
-            input_subkeys = input_dict["reciprocal"].keys()
+            input_sub_keys = input_dict["reciprocal"].keys()
 
         _ = [
-            [default[key].update({subkey: val[subkey]}) for subkey in input_subkeys]
+            [default[key].update({sub_key: val[sub_key]}) for sub_key in input_sub_keys]
             if key == "reciprocal"
             else default.update({key: val})
             for key, val in input_dict.items()
@@ -235,7 +236,7 @@ class Dimension:
 
         .. testsetup::
 
-            >>> x.complex_fft = False
+            x.complex_fft = False
 
         Returns:
             A Quantity array of absolute coordinates for quantitative dimensions, `i.e`
@@ -253,20 +254,15 @@ class Dimension:
         .. doctest::
 
             >>> print(x.application)
-            {}
+            None
 
-        The application attribute is where an application can place its own
-        metadata as a python dictionary object containing application specific
-        metadata, using a reverse domain name notation string as the attribute
-        key, for example,
+        The application attribute is where an application can place its metadata as a
+        python dictionary object using a reverse domain name notation string as the
+        attribute key, for example,
 
         .. doctest::
 
-            >>> x.application = {
-            ...     "com.example.myApp" : {
-            ...         "myApp_key": "myApp_metadata"
-            ...      }
-            ... }
+            >>> x.application = {"com.example.myApp": {"myApp_key": "myApp_metadata"}}
             >>> print(x.application)
             {'com.example.myApp': {'myApp_key': 'myApp_metadata'}}
 
@@ -285,7 +281,7 @@ class Dimension:
 
         This attribute is not a part of the original core scientific dataset
         model, however, it is a convenient supplementary attribute that provides
-        a formated string ready for labeling dimension axes.
+        a formatted string ready for labeling dimension axes.
         For quantitative dimensions, this attributes returns a string,
         `label / unit`,  if the `label` is a non-empty string, otherwise,
         `quantity_name / unit`. Here
@@ -304,7 +300,7 @@ class Dimension:
         For `labeled` dimensions, this attribute returns `label`.
 
         Returns:
-            A formated string of label.
+            A formatted string of label.
 
         Raises:
             AttributeError: When assigned a value.
@@ -332,7 +328,7 @@ class Dimension:
 
         .. testsetup::
 
-            >>> x.complex_fft = False
+            x.complex_fft = False
 
         Returns:
             A Quantity array of coordinates for quantitative dimensions, `i.e.` `linear`
@@ -377,7 +373,10 @@ class Dimension:
               "origin_offset": "10.0 T",
               "quantity_name": "magnetic flux density",
               "label": "field strength",
-              "description": "This is a test"
+              "description": "This is a test",
+              "reciprocal": {
+                "quantity_name": "electrical mobility"
+              }
             }
 
         Returns:
@@ -399,7 +398,7 @@ class Dimension:
             >>> print(x.description)
             This is a test
 
-            >>> x.description = 'This is a test dimension.'
+            >>> x.description = "This is a test dimension."
 
         Returns:
             A string of UTF-8 allows characters describing the dimension.
@@ -426,7 +425,7 @@ class Dimension:
 
         .. doctest::
 
-            >>> test = Dimension(type='linear', increment = '1', count = 10)
+            >>> test = Dimension(type="linear", increment="1", count=10)
             >>> test.complex_fft
             False
             >>> print(test.coordinates)
@@ -600,9 +599,9 @@ class Dimension:
 
         .. doctest::
 
-            >>> x.period = '1/0 T'
-            >>> x.period = 'infinity µT'
-            >>> x.period = '∞ G'
+            >>> x.period = "1/0 T"
+            >>> x.period = "infinity µT"
+            >>> x.period = "∞ G"
 
         .. Attention::
             The physical quantity of the period must be consistent with other
@@ -640,7 +639,7 @@ class Dimension:
             AttributeError: For `labeled` dimensions.
             NotImplementedError: When assigning a value.
         """
-        return self.subtype.quantity_name
+        return str(self.subtype.quantity_name)
 
     @quantity_name.setter
     def quantity_name(self, value):
@@ -674,12 +673,9 @@ class Dimension:
 
         .. doctest::
 
-            >>> x2 = Dimension(
-            ...         type='labeled',
-            ...         labels=['Cu', 'Ag', 'Au']
-            ...      )
+            >>> x2 = Dimension(type="labeled", labels=["Cu", "Ag", "Au"])
 
-        then the lables along the labeled dimension are
+        then the labels along the labeled dimension are
 
         .. doctest::
 
@@ -730,7 +726,7 @@ class Dimension:
     #                           Dimension Methods                             #
     # ======================================================================= #
 
-    def _copy_metadata(self, obj, copy=False):
+    def _copy_metadata(self, obj):
         """Copy Dimension metadata"""
         self.subtype._type = obj.subtype._type
         self.subtype._copy_metadata(obj)
@@ -789,11 +785,11 @@ class Dimension:
         return deepcopy(self)
 
     def reciprocal_coordinates(self):
-        """Return reciprocal coordinates assuming Nyquist-shannan theorem."""
+        """Return reciprocal coordinates assuming Nyquist-Shannon theorem."""
         return self.subtype.reciprocal_coordinates()
 
     def reciprocal_increment(self):
-        """Return reciprocal increment assuming Nyquist-shannan theorem."""
+        """Return reciprocal increment assuming Nyquist-Shannon theorem."""
         return self.subtype.reciprocal_coordinates()
 
 
@@ -851,14 +847,16 @@ def __check_array_for_dimension__(array, type):
         raise ValueError(f"Cannot convert {name} to a Dimension object.")
 
     array = np.asarray(array)
-    n = array.ndim
-    if n == 1:
+    n_dim = array.ndim
+    if n_dim == 1:
         return array
 
-    raise ValueError(f"Cannot convert a {n} dimensional array to a Dimension object.")
+    raise ValueError(
+        f"Cannot convert a {n_dim} dimensional array to a Dimension object."
+    )
 
 
-def _generic_dimensions(array, unit, className="Dimension", **kwargs):
+def _generic_dimensions(array, unit, class_name="Dimension", **kwargs):
     """Return a dimension object based on the array coordinates."""
     # labeled
     if str(array.dtype)[:2] in [">U", "<U"]:
@@ -867,7 +865,7 @@ def _generic_dimensions(array, unit, className="Dimension", **kwargs):
         return LabeledDimension(labels=array.tolist(), **kwargs)
 
     # linear
-    obj = _linear_dimension(array, unit, className, **kwargs)
+    obj = _linear_dimension(array, unit, class_name, **kwargs)
     if obj is not None:
         return obj
 
@@ -879,11 +877,11 @@ def _generic_dimensions(array, unit, className="Dimension", **kwargs):
     raise ValueError("Invalid array for Dimension object.")
 
 
-def _linear_dimension(array, unit, className="LinearDimension", **kwargs):
+def _linear_dimension(array, unit, class_name="LinearDimension", **kwargs):
     """Return a LinearDimension is array is linear, else None."""
     increment = array[1] - array[0]
     if increment == 0:
-        raise ValueError(f"Invalid array for {className} object.")
+        raise ValueError(f"Invalid array for {class_name} object.")
 
     if np.allclose(np.diff(array, 1), increment):
         unit = f"({unit})" if str(unit) != "" else ""
