@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Helper functions."""
 from copy import deepcopy
 from warnings import warn
@@ -178,6 +177,8 @@ class CSDMAxes(plt.Axes):
         z = csdm.split()
         one = True if len(z) == 1 else False
         legend = False
+
+        r_plt = None
         for i, item in enumerate(z):
             x_, y_ = item.to_list()
             # dv will always be at index 0 because we called the object.split() before.
@@ -205,6 +206,9 @@ class CSDMAxes(plt.Axes):
         if legend:
             self.legend()
 
+        if r_plt is None:
+            raise NotImplementedError("Cannot plot dataset")
+
         return r_plt
 
     def _call_uniform_2D_contour(self, csdm, fn, *args, **kwargs):
@@ -216,16 +220,15 @@ class CSDMAxes(plt.Axes):
         x0, x1 = x[0].coordinates.value, x[1].coordinates.value
 
         # add cmap for multiple dependent variables.
-        cmaps_bool = False
-        if "cmaps" in kw_keys:
-            cmaps_bool = True
-            cmaps = kwargs.pop("cmaps")
+        cmaps_bool = True if "cmaps" in kw_keys else False
+        cmaps = kwargs.pop("cmaps") if cmaps_bool else None
 
         one = True if len(csdm.dependent_variables) == 1 else False
 
+        r_plt = None
         for i, dv in enumerate(csdm.dependent_variables):
             y = dv.components
-            if dv.quantity_type == "scalar":
+            if dv.quantity_type in ["scalar", "vector_1", "pixel_1"]:
                 if cmaps_bool:
                     kwargs["cmap"] = cmaps[i]
 
@@ -240,6 +243,9 @@ class CSDMAxes(plt.Axes):
         self.set_ylabel(x[1].axis_label)
         if one:
             self.set_title(dv.name)
+
+        if r_plt is None:
+            raise NotImplementedError("Cannot plot dataset")
         return r_plt
 
     def _call_uniform_2D_image(self, csdm, *args, **kwargs):
@@ -257,16 +263,15 @@ class CSDMAxes(plt.Axes):
             kwargs["extent"] = extent
 
         # add cmap for multiple dependent variables.
-        cmaps_bool = False
-        if "cmaps" in kw_keys:
-            cmaps_bool = True
-            cmaps = kwargs.pop("cmaps")
+        cmaps_bool = True if "cmaps" in kw_keys else False
+        cmaps = kwargs.pop("cmaps") if cmaps_bool else None
 
         one = True if len(csdm.dependent_variables) == 1 else False
 
+        r_plt = None
         for i, dv in enumerate(csdm.dependent_variables):
             y = dv.components
-            if dv.quantity_type == "scalar":
+            if dv.quantity_type in ["scalar", "vector_1", "pixel_1"]:
                 if cmaps_bool:
                     kwargs["cmap"] = cmaps[i]
 
@@ -282,6 +287,9 @@ class CSDMAxes(plt.Axes):
         self.set_ylabel(x[1].axis_label)
         if one:
             self.set_title(dv.name)
+
+        if r_plt is None:
+            raise NotImplementedError("Cannot plot dataset")
         return r_plt
 
 
@@ -297,7 +305,7 @@ def _check_1D_dataset(csdm):
     message = (
         "The function requires a 1D dataset with single-component dependent "
         "variables. For multiple dependent-variables, the data from all the "
-        "dependent variables are ploted on the same figure."
+        "dependent variables are plotted on the same figure."
     )
     if len(x) != 1:
         raise Exception(message)
@@ -425,7 +433,7 @@ def oneD_scalar(x, y, ax, range_, **kwargs):
         ax.set_xlim(x[0].coordinates.value.min(), x[0].coordinates.value.max())
         ax.set_xlabel(f"{x[0].axis_label} - 0")
         ax.set_ylabel(y.axis_label[0])
-        ax.set_title("{0}".format(y.name))
+        ax.set_title(f"{y.name}")
         ax.grid(color="gray", linestyle="--", linewidth=0.5)
 
     ax.set_xlim(range_[0])
@@ -470,7 +478,7 @@ def twoD_scalar(x, y, ax, range_, **kwargs):
     ax.set_ylim([extent[2], extent[3]])
     ax.set_xlabel(f"{x[0].axis_label} - 0")
     ax.set_ylabel(f"{x[1].axis_label} - 1")
-    ax.set_title("{0}".format(y.name))
+    ax.set_title(f"{y.name}")
     ax.grid(color="gray", linestyle="--", linewidth=0.5)
 
     ax.set_xlim(range_[0])
@@ -510,7 +518,7 @@ def vector_plot(x, y, ax, range_, **kwargs):
             ax.invert_yaxis()
     else:
         ax.set_ylim([-y.components.max(), y.components.max()])
-    ax.set_title("{0}".format(y.name))
+    ax.set_title(f"{y.name}")
     ax.grid(color="gray", linestyle="--", linewidth=0.5)
 
     ax.set_xlim(range_[0])
@@ -528,7 +536,7 @@ def RGB_image(x, y, ax, range_, **kwargs):
 
     y0 = y.components
     ax.imshow(np.moveaxis(y0 / y0.max(), 0, -1), **kwargs)
-    ax.set_title("{0}".format(y.name))
+    ax.set_title(f"{y.name}")
 
     ax.set_xlim(range_[0])
     ax.set_ylim(range_[1])
