@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """Helper methods for CSDM class."""
-from __future__ import print_function
-
 from copy import deepcopy
 
 import numpy as np
@@ -367,12 +364,13 @@ def _check_dimension_indices(d, index=-1):
         return -1 - i
 
     message = "Index/Indices are expected as integer(s)"
+    # convert to list and correct the list elements in the following section.
     if isinstance(index, tuple):
         index = list(index)
-    if isinstance(index, (list, np.ndarray)):
+    if isinstance(index, (tuple, list, np.ndarray)):
         for i, item in enumerate(index):
             index[i] = _correct_index(item, d)
         return tuple(index)
     if isinstance(index, int):
-        return tuple([_correct_index(index, d)])
+        return _correct_index(index, d)
     raise TypeError(f"{message}, found {type(index)}")
