@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import json
 
 import numpy as np
@@ -11,14 +10,13 @@ from csdmpy.units import ScalarQuantity
 
 # linear dimension
 def test_linear_new():
-    data = cp.new()
     dim = {
         "type": "linear",
         "increment": "10 m/s",
         "count": 10,
         "coordinates_offset": "5 m/s",
     }
-    data.dimensions.append(dim)
+    data = cp.CSDM(dimensions=[dim])
 
     assert data.dimensions[0].is_quantitative() is True
 
@@ -30,7 +28,7 @@ def test_linear_new():
     assert data.dimensions[0].type == "linear"
 
     error = "can't set attribute"
-    with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+    with pytest.raises(AttributeError, match=f".*{error}.*"):
         data.dimensions[0].type = "monotonic"
 
     # increment
@@ -41,25 +39,25 @@ def test_linear_new():
     assert str(data.dimensions[0].increment) == "20.0 m / s"
 
     error = "Expecting an instance of type"
-    with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+    with pytest.raises(TypeError, match=f".*{error}.*"):
         data.dimensions[0].increment = 10
 
     data.dimensions[0].increment = "20/2 m / s"
     assert str(data.dimensions[0].increment) == "10.0 m / s"
 
     # application
-    assert data.dimensions[0].application == {}
+    assert data.dimensions[0].application is None
     data.dimensions[0].application = {"my_application": {}}
     assert data.dimensions[0].application == {"my_application": {}}
     error = "Expecting an instance of type"
-    with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+    with pytest.raises(TypeError, match=f".*{error}.*"):
         data.dimensions[0].application = "my_application"
 
     # coordinates offset
     assert str(data.dimensions[0].coordinates_offset) == "5.0 m / s"
 
     error = "Expecting an instance of type"
-    with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+    with pytest.raises(TypeError, match=f".*{error}.*"):
         data.dimensions[0].coordinates_offset = 50
 
     data.dimensions[0].coordinates_offset = ScalarQuantity("5.0 m / s")
@@ -111,11 +109,11 @@ def test_linear_new():
     test_with = (np.arange(12) - 6) * 20.0 + 5.0 + 1000.0
     assert np.all(data.dimensions[0].absolute_coordinates.value == test_with)
 
-    error = "The attribute cannot be modifed for Dimension objects with"
-    with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+    error = "The attribute cannot be modified for Dimension objects with"
+    with pytest.raises(AttributeError, match=f".*{error}.*"):
         data.dimensions[0].coordinates = [1, 3]
 
-    with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+    with pytest.raises(AttributeError, match=f".*{error}.*"):
         data.x[0].coords = [1, 3]
 
     data.dimensions[0].reciprocal.description = "blah blah"
@@ -190,44 +188,44 @@ def test_linear_new():
 
 
 def test_linearDimension():
-    a = cp.LinearDimension(count=3, increment="2s")
-    ap = cp.Dimension(type="linear", count=3, increment="2s")
+    dim_1 = cp.LinearDimension(count=3, increment="2s")
+    dim_2 = cp.Dimension(type="linear", count=3, increment="2s")
 
     message = "LinearDimension([0. 2. 4.] s)"
-    assert a.__str__() == message
-    assert ap.__str__() == message
+    assert dim_1.__str__() == message
+    assert dim_2.__str__() == message
 
     message = (
         "LinearDimension(count=3, increment=2.0 s, "
         "quantity_name=time, reciprocal={'quantity_name': 'frequency'})"
     )
-    assert a.__repr__() == message
-    assert ap.__repr__() == message
+    assert dim_1.__repr__() == message
+    assert dim_2.__repr__() == message
 
-    assert a != 2
-    assert a.is_quantitative() is True
+    assert dim_1 != 2
+    assert dim_1.is_quantitative() is True
 
-    b = cp.as_dimension(np.arange(3) * 2)
-    assert a / cp.ScalarQuantity("1s") == b
-    assert a * cp.ScalarQuantity("s^-1") == b
-    assert ap / cp.ScalarQuantity("1s") == b
-    assert ap * cp.ScalarQuantity("s^-1") == b
+    dim_3 = cp.as_dimension(np.arange(3) * 2)
+    assert dim_1 / cp.ScalarQuantity("1s") == dim_3
+    assert dim_1 * cp.ScalarQuantity("s^-1") == dim_3
+    assert dim_2 / cp.ScalarQuantity("1s") == dim_3
+    assert dim_2 * cp.ScalarQuantity("s^-1") == dim_3
 
-    b *= cp.ScalarQuantity("1s")
-    assert a == b
-    assert ap == b
+    dim_3 *= cp.ScalarQuantity("1s")
+    assert dim_1 == dim_3
+    assert dim_2 == dim_3
 
-    b /= cp.ScalarQuantity("s")
-    a *= cp.ScalarQuantity("s^-1")
-    ap *= cp.ScalarQuantity("s^-1")
-    assert a == b
-    assert ap == b
+    dim_3 /= cp.ScalarQuantity("s")
+    dim_1 *= cp.ScalarQuantity("s^-1")
+    dim_2 *= cp.ScalarQuantity("s^-1")
+    assert dim_1 == dim_3
+    assert dim_2 == dim_3
 
-    ap = cp.Dimension(type="linear", count=3, increment="2s")
-    ap /= cp.ScalarQuantity("s")
-    assert ap == cp.as_dimension(np.arange(3) * 2)
+    dim_2 = cp.Dimension(type="linear", count=3, increment="2s")
+    dim_2 /= cp.ScalarQuantity("s")
+    assert dim_2 == cp.as_dimension(np.arange(3) * 2)
 
-    assert a.count == 3
+    assert dim_1.count == 3
 
     freq = cp.LinearDimension(
         count=10, increment="100 Hz", origin_offset="1 MHz", coordinates_offset="1kHz"
@@ -262,14 +260,12 @@ def test_linearDimension():
 
 # monotonic dimension
 def test_monotonic_new():
-    data = cp.new()
-    dim = {
-        "type": "monotonic",
-        "description": "Far far away.",
-        "coordinates": ["1 m", "100 m", "1 km", "1 Gm", "0.25 lyr"],
-    }
-    data.dimensions.append(dim)
-    data.add_x(dim)
+    dim_x = cp.Dimension(
+        type="monotonic",
+        description="Far far away.",
+        coordinates=["1 m", "100 m", "1 km", "1 Gm", "0.25 lyr"],
+    )
+    data = cp.CSDM(dimensions=[dim_x, dim_x.copy()])
 
     for dim in data.dimensions:
         assert dim.is_quantitative() is True
@@ -280,7 +276,7 @@ def test_monotonic_new():
         assert dim.description == "A galaxy far far away."
 
         error = "Expecting an instance of type"
-        with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+        with pytest.raises(TypeError, match=f".*{error}.*"):
             dim.description = 12
 
         # dimension type
@@ -297,7 +293,7 @@ def test_monotonic_new():
 
         # increment
         error = "'MonotonicDimension' object has no attribute 'increment'"
-        with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+        with pytest.raises(AttributeError, match=f".*{error}.*"):
             _ = dim.increment
 
         # label
@@ -306,26 +302,26 @@ def test_monotonic_new():
         assert dim.label == "some string"
 
         error = "Expecting an instance of type"
-        with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+        with pytest.raises(TypeError, match=f".*{error}.*"):
             dim.label = {}
 
         # count
         assert dim.count == 5
         error = "Cannot set the count,"
-        with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+        with pytest.raises(ValueError, match=f".*{error}.*"):
             dim.count = 12
 
         error = "Expecting an instance of type"
-        with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+        with pytest.raises(TypeError, match=f".*{error}.*"):
             dim.count = "12"
 
         # coordinates_offset
         error = "`MonotonicDimension` has no attribute `coordinates_offset`."
-        with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+        with pytest.raises(AttributeError, match=f".*{error}.*"):
             _ = dim.coordinates_offset
 
         error = "can't set attribute"
-        with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+        with pytest.raises(AttributeError, match=f".*{error}.*"):
             dim.coordinates_offset = "1"
 
         # origin offset
@@ -338,14 +334,14 @@ def test_monotonic_new():
         assert str(dim.origin_offset) == "1.0 lyr"
 
         error = "Expecting an instance of type"
-        with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+        with pytest.raises(TypeError, match=f".*{error}.*"):
             dim.origin_offset = {"12 m"}
 
         # quantity_name
         assert dim.quantity_name == "length"
 
         error = "This attribute is not yet implemented"
-        with pytest.raises(NotImplementedError, match=".*{0}.*".format(error)):
+        with pytest.raises(NotImplementedError, match=f".*{error}.*"):
             dim.quantity_name = "area/length"
 
         # period
@@ -360,12 +356,12 @@ def test_monotonic_new():
         assert str(dim.period) == "1.0 m"
 
         error = "Expecting an instance of type `str` for period, got `int`."
-        with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+        with pytest.raises(TypeError, match=f".*{error}.*"):
             dim.period = 1
 
         # fft output order
         error = "'MonotonicDimension' object has no attribute 'complex_fft'"
-        with pytest.raises(AttributeError, match=".*{0}.*".format(error)):
+        with pytest.raises(AttributeError, match=f".*{error}.*"):
             _ = dim.complex_fft
 
     # coordinates
@@ -431,9 +427,9 @@ def test_monotonic_new():
     assert data.dimensions[0].to_dict() == dict1["csdm"]["dimensions"][0]
 
     error = r"The unit 's' \(time\) is inconsistent with the unit 'm' \(length\)"
-    with pytest.raises(Exception, match=".*{0}.*".format(error)):
+    with pytest.raises(Exception, match=f".*{error}.*"):
         data.dimensions[0].coordinates = ["1s", "2s"]
-    with pytest.raises(Exception, match=".*{0}.*".format(error)):
+    with pytest.raises(Exception, match=f".*{error}.*"):
         data.x[0].coords = ["1s", "2s"]
 
     data.dimensions[0].coordinates = ["1m", "2m"]
@@ -455,25 +451,25 @@ def test_monotonic_new():
 
 
 def test_monotonicDimension():
-    a = cp.MonotonicDimension(coordinates=10 ** (np.arange(2)))
-    assert a.__str__() == "MonotonicDimension([ 1. 10.])"
+    dim_1 = cp.MonotonicDimension(coordinates=10 ** (np.arange(2)))
+    assert dim_1.__str__() == "MonotonicDimension([ 1. 10.])"
 
-    assert a.__repr__() == ("MonotonicDimension(coordinates=[ 1. 10.])")
+    assert dim_1.__repr__() == ("MonotonicDimension(coordinates=[ 1. 10.])")
 
-    assert a != 2
-    assert a.is_quantitative() is True
+    assert dim_1 != 2
+    assert dim_1.is_quantitative() is True
 
-    b = cp.as_dimension([1, 10], type="monotonic") * cp.ScalarQuantity("s")
-    assert b / cp.ScalarQuantity("1s") == cp.as_dimension([1, 10], type="monotonic")
-    assert a * cp.ScalarQuantity("s") == b
+    dim_2 = cp.as_dimension([1, 10], type="monotonic") * cp.ScalarQuantity("s")
+    assert dim_2 / cp.ScalarQuantity("1s") == cp.as_dimension([1, 10], type="monotonic")
+    assert dim_1 * cp.ScalarQuantity("s") == dim_2
 
-    b /= cp.ScalarQuantity("s")
-    a *= cp.ScalarQuantity("s^-1")
-    assert a * cp.ScalarQuantity("1s") == b
+    dim_2 /= cp.ScalarQuantity("s")
+    dim_1 *= cp.ScalarQuantity("s^-1")
+    assert dim_1 * cp.ScalarQuantity("1s") == dim_2
 
-    b.count = 1
-    assert b.coordinates.value == [1]
-    assert b.coords.value == [1]
+    dim_2.count = 1
+    assert dim_2.coordinates.value == [1]
+    assert dim_2.coords.value == [1]
 
     ratio = cp.as_dimension([1, 10], type="monotonic") * cp.ScalarQuantity("Hz")
     ratio.origin_offset = "1 MHz"
@@ -491,16 +487,16 @@ def test_monotonicDimension():
     assert np.allclose(ratio.coords.value, [0.0, 10])
 
     error = r"The unit '' \(dimensionless\) is inconsistent with the unit 'Hz'"
-    with pytest.raises(Exception, match=".*{0}.*".format(error)):
+    with pytest.raises(Exception, match=f".*{error}.*"):
         ratio.coordinates = ["0 ", "10 "]
-    with pytest.raises(Exception, match=".*{0}.*".format(error)):
+    with pytest.raises(Exception, match=f".*{error}.*"):
         ratio.coords = ["0 ", "10 "]
 
     ratio.origin_offset = "0 Hz"
     error = "Cannot convert the coordinates to ppm."
-    with pytest.raises(ZeroDivisionError, match=".*{0}.*".format(error)):
+    with pytest.raises(ZeroDivisionError, match=f".*{error}.*"):
         _ = ratio.coordinates
-    with pytest.raises(ZeroDivisionError, match=".*{0}.*".format(error)):
+    with pytest.raises(ZeroDivisionError, match=f".*{error}.*"):
         _ = ratio.coords
 
     assert ratio.axis_label == "frequency / (ppm)"
@@ -536,7 +532,7 @@ def test_labeled_new():
     assert data.dimensions[0].description == "A galaxy far far away."
 
     error = "Expecting an instance of type"
-    with pytest.raises(TypeError, match=".*{0}.*".format(error)):
+    with pytest.raises(TypeError, match=f".*{error}.*"):
         data.dimensions[0].description = 12
 
     assert data.dimensions[0].labels[0] == "m"
@@ -544,11 +540,11 @@ def test_labeled_new():
     assert data.x[0].coords[-1] == "a"
 
     error = "A list of labels is required"
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         data.dimensions[0].labels = 12
 
     error = "A list of string labels are required"
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         data.dimensions[0].labels = ["12", "1", 4]
 
     data.dimensions[0].label = "labeled dimension"
@@ -596,52 +592,52 @@ def test_labeled_new():
 
 
 def test_labeledDimension():
-    a = cp.as_dimension(["1", "a", "c"])
+    dim_1 = cp.as_dimension(["1", "a", "c"])
 
-    assert a.__str__() == "LabeledDimension(['1' 'a' 'c'])"
+    assert dim_1.__str__() == "LabeledDimension(['1' 'a' 'c'])"
 
-    assert a.__repr__() == ("LabeledDimension(labels=['1', 'a', 'c'])")
+    assert dim_1.__repr__() == ("LabeledDimension(labels=['1', 'a', 'c'])")
 
-    assert a.type == "labeled"
-    assert a != 1
-    assert a.is_quantitative() is False
-    assert a.count == 3
+    assert dim_1.type == "labeled"
+    assert dim_1 != 1
+    assert dim_1.is_quantitative() is False
+    assert dim_1.count == 3
 
     error = "Cannot set the count, 4, more than the number of coordinates"
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
-        a.count = 4
+    with pytest.raises(ValueError, match=f".*{error}.*"):
+        dim_1.count = 4
 
-    a.count = 2
-    assert a.count == 2
+    dim_1.count = 2
+    assert dim_1.count == 2
 
-    assert a == a.copy()
+    assert dim_1 == dim_1.copy()
 
 
 def test_as_dimension():
-    a = np.arange(10)
+    array = np.arange(10)
     one = np.ones(10)
     rand = np.random.rand(10)
-    monotonic = 10 ** a / 10
+    monotonic = 10**array / 10
 
-    dim = cp.as_dimension(a, unit="s")
-    assert np.allclose(dim.coordinates.value, a)
-    assert np.allclose(dim.coords.value, a)
+    dim = cp.as_dimension(array, unit="s")
+    assert np.allclose(dim.coordinates.value, array)
+    assert np.allclose(dim.coords.value, array)
 
     # linear
     error = "Invalid array for Dimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension(one, unit="s")
 
-    dim = cp.as_dimension(a, unit="s", type="linear")
-    assert np.allclose(dim.coordinates.value, a)
+    dim = cp.as_dimension(array, unit="s", type="linear")
+    assert np.allclose(dim.coordinates.value, array)
 
     # linear with type
     error = "Invalid array for LinearDimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension(one, unit="s", type="linear")
 
     error = "Invalid array for LinearDimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension(one, unit="s", type="linear")
 
     # monotonic
@@ -655,11 +651,11 @@ def test_as_dimension():
     assert np.allclose(dim.coords.value, monotonic)
 
     error = "Invalid array for Dimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension(rand, unit="s")
 
     error = "Invalid array for MonotonicDimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension(rand, unit="s", type="monotonic")
 
     # labeled
@@ -674,13 +670,22 @@ def test_as_dimension():
 
     # error
     error = "Invalid value for `type`. Allowed values are"
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
-        cp.as_dimension(a, type="log-linear")
+    with pytest.raises(ValueError, match=f".*{error}.*"):
+        cp.as_dimension(array, type="log-linear")
 
     error = "to a Dimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension({"a": [1, 2, 3]})
 
     error = "Cannot convert a 2 dimensional array to a Dimension object."
-    with pytest.raises(ValueError, match=".*{0}.*".format(error)):
+    with pytest.raises(ValueError, match=f".*{error}.*"):
         cp.as_dimension(np.arange(100).reshape(10, 10))
+
+
+def test_dimension_scale():
+    """Test for unit physical type in astropy>=4.0"""
+    dim = cp.LinearDimension(count=10, increment="1m")
+    dim2 = dim / 2.4
+    assert np.allclose(dim2.coordinates.value, np.arange(10) / 2.4)
+    assert dim2.quantity_name == "length"
+    assert type(dim2.quantity_name) == str
