@@ -1,22 +1,19 @@
-# -*- coding: utf-8 -*-
 from os import remove
 
 import csdmpy as cp
 
 
 def setup():
-    data = cp.new(description="An emoji dataset")
-
-    x = dict(type="labeled", labels=["🍈", "🍉", "🍋", "🍌", "🥑", "🍍"])
-    data.add_dimension(x)
-
-    y = dict(
+    d_x = cp.Dimension(type="labeled", labels=["🍈", "🍉", "🍋", "🍌", "🥑", "🍍"])
+    d_y = cp.DependentVariable(
         type="internal",
         numeric_type="float32",
         quantity_type="scalar",
         components=[[0.5, 0.25, 1, 2, 1, 0.25]],
     )
-    data.add_dependent_variable(y)
+    data = cp.CSDM(
+        description="An emoji dataset", dimensions=[d_x], dependent_variables=[d_y]
+    )
     return data
 
 
@@ -28,14 +25,14 @@ def test_csdf_base64():
 
 def test_csdf_none():
     data = setup()
-    data.dependent_variables[0].encoding = "none"
+    data.y[0].encoding = "none"
     data.save("my_file_none.csdf")
     remove("my_file_none.csdf")
 
 
 def test_csdfe():
     data = setup()
-    data.dependent_variables[0].encoding = "raw"
+    data.y[0].encoding = "raw"
     data.save("my_file_raw.csdfe")
     remove("my_file_raw.csdfe")
     remove("my_file_raw_0.dat")
